package br.pucrs.ages.victims.auth.mapper

import br.pucrs.ages.victims.auth.domain.User
import br.pucrs.ages.victims.auth.repository.keycloak.APPLICATION_ID
import br.pucrs.ages.victims.auth.repository.keycloak.PHONE_NUMBER
import org.keycloak.representations.idm.UserRepresentation
import org.springframework.stereotype.Component
import java.util.*

@Component
class UserMapper {

    fun fromRepresentationToDomain(representation: UserRepresentation): User {
        return User(
            id = UUID.fromString(representation.id),
            name = representation.firstName,
            email = representation.email,
            phoneNumber = representation.attributes["phone_number"]?.firstOrNull() ?: "",
            cpf = representation.username,
            isDeleted = representation.isEnabled
        )
    }

    fun toRepresentation(user: User): UserRepresentation {
        val userRepresentation = UserRepresentation()

        userRepresentation.username = user.cpf
        userRepresentation.email = user.email
        userRepresentation.firstName = user.name
        userRepresentation.isEnabled = true
        userRepresentation.isEmailVerified = true

        userRepresentation.attributes = mapOf(
            APPLICATION_ID to listOf(user.id.toString()),
            PHONE_NUMBER to listOf(user.phoneNumber)
        )

        return userRepresentation
    }


}
