package br.pucrs.ages.victims.auth.repository.keycloak

import br.pucrs.ages.victims.auth.config.properties.KeycloakProperties
import br.pucrs.ages.victims.auth.domain.User
import br.pucrs.ages.victims.auth.exception.NotFoundException
import br.pucrs.ages.victims.auth.mapper.UserMapper
import br.pucrs.ages.victims.auth.repository.UserRepository
import org.keycloak.admin.client.Keycloak
import org.keycloak.representations.idm.CredentialRepresentation
import org.keycloak.representations.idm.UserRepresentation
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Repository
import java.util.*

@Repository
class UserRepositoryImpl(
    @Autowired
    val keycloak: Keycloak,
    @Autowired
    private val userMapper: UserMapper,
    @Autowired
    val keycloakProperties: KeycloakProperties
) : UserRepository {

    fun findById(id: UUID): Optional<UserRepresentation> =
        keycloak.realm(keycloakProperties.realm)
            .users()
            .searchByAttributes("$APPLICATION_ID:$id").stream()
            .findFirst()

    override fun findByCpf(cpf: String): Optional<User> {
        return keycloak.realm(keycloakProperties.realm)
            .users().search(cpf).stream()
            .findFirst()
            .map { userMapper.fromRepresentationToDomain(it) }
    }

    override fun findByEmail(email: String): Optional<User> {
        return keycloak.realm(keycloakProperties.realm)
            .users().searchByEmail(email, true).stream()
            .findFirst()
            .map { userMapper.fromRepresentationToDomain(it) }
    }

    override fun save(user: User): User {
        keycloak.realm(keycloakProperties.realm).users().create(userMapper.toRepresentation(user))

        return user
    }

    override fun updatePasswordById(id: UUID, password: String) {
        val user = findById(id)
            .orElseThrow { NotFoundException("User not found.") }

        keycloak.realm(keycloakProperties.realm).users().get(user.id)
            .resetPassword(buildCredentialRepresentation(password))
    }

    private fun buildCredentialRepresentation(password: String): CredentialRepresentation {
        val credential = CredentialRepresentation()
        credential.type = CredentialRepresentation.PASSWORD
        credential.value = password
        credential.isTemporary = false
        return credential
    }

}