package br.pucrs.ages.victims.auth.service

import br.pucrs.ages.victims.auth.domain.User
import br.pucrs.ages.victims.auth.exception.ExistingResourceException
import br.pucrs.ages.victims.auth.repository.UserRepository
import br.pucrs.ages.victims.auth.validator.UserValidator
import br.pucrs.ages.victims.auth.web.representation.request.RegisterRequestModel
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Service

@Service
class UserService(

    @Autowired
    val userRepository: UserRepository,

    @Autowired
    val userValidator: UserValidator
) {
    fun create(payload: RegisterRequestModel): User {
        val userFoundByCpf = userRepository.findByCpf(payload.cpf)

        if (userFoundByCpf.isPresent) {
            throw ExistingResourceException("Um usuário com esse CPF já está cadastrado")
        }

        val userFoundByEmail = userRepository.findByEmail(payload.email)

        if (userFoundByEmail.isPresent) {
            throw ExistingResourceException("Um usuário com esse email já está cadastrado")
        }

        userValidator.validatePayload(payload)

        val newUser = User(
            email = payload.email,
            name = payload.name,
            cpf = payload.cpf,
            phoneNumber = payload.phoneNumber,
            isDeleted = false
        )

        userRepository.save(newUser)
        userRepository.updatePasswordById(newUser.id, payload.password)

        return newUser
    }

}