package br.pucrs.ages.victims.auth.validator

import br.pucrs.ages.victims.auth.exception.ValidationException
import br.pucrs.ages.victims.auth.web.representation.request.RegisterRequestModel
import org.springframework.stereotype.Component

const val MIN_PASSWORD_SIZE: Int = 8

@Component
class UserValidator {

    fun validatePayload(payload: RegisterRequestModel) {
        if (!isPasswordValid(payload.password)) {
            throw ValidationException("Senha inválida")
        }

        if (!isPasswordValid(payload.securityPassword)) {
            throw ValidationException("Senha de segurança inválida")
        }

        if (payload.password == payload.securityPassword) {
            throw ValidationException("As senha de segurança deve ser diferente da senha principal")
        }

        if (!payload.phoneNumber.all { it.isDigit() }) {
            throw ValidationException("O telefone deve conter apenas números")
        }

    }


    private fun isPasswordValid(password: String): Boolean {
        return password.length >= MIN_PASSWORD_SIZE &&
                password.firstOrNull { it.isDigit() } != null &&
                password.filter { it.isLetter() }.firstOrNull { it.isUpperCase() } != null &&
                password.filter { it.isLetter() }.firstOrNull { it.isLowerCase() } != null
    }
}