package br.pucrs.ages.victims.auth.web

import br.pucrs.ages.victims.auth.domain.dto.JwtTokenDTO
import br.pucrs.ages.victims.auth.web.representation.request.LoginRequestModel
import io.swagger.v3.oas.annotations.Operation
import io.swagger.v3.oas.annotations.responses.ApiResponse
import io.swagger.v3.oas.annotations.responses.ApiResponses
import io.swagger.v3.oas.annotations.tags.Tag
import org.springframework.http.ResponseEntity

@Tag(name = "Auth", description = "Operações com autenticação e autorização")
interface AuthApi {

    @Operation(summary = "Autentica um usuário no Keycloak e retorna um token JWT")
    @ApiResponses(
        value = [
            ApiResponse(responseCode = "200", description = "Token JWT gerado com sucesso"),
            ApiResponse(responseCode = "400", description = "Payload inválido"),
            ApiResponse(responseCode = "401", description = "Credenciais inválidas"),
            ApiResponse(responseCode = "404", description = "Recurso não encontrado"),
            ApiResponse(responseCode = "500", description = "Erro interno")
        ]
    )
    fun login(payload: LoginRequestModel): ResponseEntity<JwtTokenDTO>
}