package br.pucrs.ages.victims.auth.web.error

import br.pucrs.ages.victims.auth.exception.*
import br.pucrs.ages.victims.auth.web.representation.response.ErrorResponse
import org.springframework.http.ResponseEntity
import org.springframework.security.access.AccessDeniedException
import org.springframework.security.oauth2.server.resource.InvalidBearerTokenException
import org.springframework.web.bind.MethodArgumentNotValidException
import org.springframework.web.bind.annotation.ControllerAdvice
import org.springframework.web.bind.annotation.ExceptionHandler

@ControllerAdvice
class GlobalExceptionHandler {

    @ExceptionHandler(MethodArgumentNotValidException::class)
    fun handleValidationExceptions(
        exception: MethodArgumentNotValidException
    ): ResponseEntity<ErrorResponse>
    {
        val errors = exception.bindingResult.allErrors

        val badRequestException = ValidationException(errors.first().defaultMessage!!)

        return buildResponseEntity(badRequestException)
    }

    @ExceptionHandler(org.springframework.security.core.AuthenticationException::class)
    fun handleAuthenticationException(
        authException: org.springframework.security.core.AuthenticationException
    ): ResponseEntity<ErrorResponse> {
        return buildResponseEntity(AuthenticationException())
    }

    @ExceptionHandler(InvalidBearerTokenException::class)
    fun handleInvalidBearerTokenException(authException: InvalidBearerTokenException): ResponseEntity<ErrorResponse> {
        return buildResponseEntity(AuthenticationException())
    }


    @ExceptionHandler(AccessDeniedException::class)
    fun handleAccessDeniedException(authException: AccessDeniedException): ResponseEntity<ErrorResponse> {
        return buildResponseEntity(AuthorizationException())
    }

    @ExceptionHandler(
        value = [
            ExistingResourceException::class,
            ValidationException::class,
            AuthenticationException::class,
            AuthorizationException::class,
            NotFoundException::class,
        ]
    )
    fun handleRestException(ex: RestException): ResponseEntity<ErrorResponse> {
        return buildResponseEntity(ex)
    }

    fun buildResponseEntity(exception: RestException): ResponseEntity<ErrorResponse> {
        val response = ErrorResponse(
            exception.message,
            exception.status
        )
        return ResponseEntity.status(exception.status).body(response)
    }

}